"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CurrentMicroOrmProvider = CurrentMicroOrmProvider;
exports.CurrentEntityManager = CurrentEntityManager;
exports.CurrentEntityRepository = CurrentEntityRepository;
exports.CurrentEntityMetadata = CurrentEntityMetadata;
exports.CheckRelationNameFactory = CheckRelationNameFactory;
exports.EntityPropsMap = EntityPropsMap;
exports.RunInTransactionFactory = RunInTransactionFactory;
exports.OrmServiceFactory = OrmServiceFactory;
exports.FindOneRowEntityFactory = FindOneRowEntityFactory;
const core_1 = require("@mikro-orm/core");
const change_case_commonjs_1 = require("change-case-commonjs");
const nestjs_1 = require("@mikro-orm/nestjs");
const json_api_nestjs_1 = require("@klerick/json-api-nestjs");
const json_api_nestjs_shared_1 = require("@klerick/json-api-nestjs-shared");
const orm_helper_1 = require("../orm-helper");
const constants_1 = require("../constants");
const service_1 = require("../service");
const micro_orm_util_service_1 = require("../service/micro-orm-util.service");
function CurrentMicroOrmProvider(connectionName) {
    return {
        provide: constants_1.CURRENT_DATA_SOURCE_TOKEN,
        useFactory: (mikroORM) => {
            return mikroORM;
        },
        inject: [connectionName ? (0, nestjs_1.getMikroORMToken)(connectionName) : core_1.MikroORM],
    };
}
function CurrentEntityManager() {
    return {
        provide: constants_1.CURRENT_ENTITY_MANAGER_TOKEN,
        useFactory: (mikroORM) => mikroORM.em,
        inject: [constants_1.CURRENT_DATA_SOURCE_TOKEN],
    };
}
function CurrentEntityRepository(entity) {
    return {
        provide: constants_1.CURRENT_ENTITY_REPOSITORY,
        useFactory: (entityManager) => entityManager.getRepository(entity),
        inject: [constants_1.CURRENT_ENTITY_MANAGER_TOKEN],
    };
}
function CurrentEntityMetadata() {
    return {
        provide: constants_1.ENTITY_METADATA_TOKEN,
        useFactory: (mikroORM) => mikroORM.getMetadata(),
        inject: [constants_1.CURRENT_DATA_SOURCE_TOKEN],
    };
}
function CheckRelationNameFactory() {
    return {
        provide: json_api_nestjs_1.CHECK_RELATION_NAME,
        inject: [micro_orm_util_service_1.MicroOrmUtilService],
        useFactory(microOrmUtilService) {
            return (entity, value) => !!microOrmUtilService.relationsName.find((i) => i === value);
        },
    };
}
function EntityPropsMap(entities) {
    return {
        provide: json_api_nestjs_1.ENTITY_PARAM_MAP,
        inject: [constants_1.ENTITY_METADATA_TOKEN, json_api_nestjs_1.MODULE_OPTIONS_TOKEN],
        useFactory: (metadataStorage, config) => {
            const mapProperty = new Map();
            const arrayConfig = config.options.arrayType;
            for (const item of entities) {
                const metadata = metadataStorage.get(item);
                const className = (0, json_api_nestjs_shared_1.getEntityName)(item);
                mapProperty.set(item, {
                    props: (0, orm_helper_1.getProps)(metadata),
                    propsType: (0, orm_helper_1.getPropsType)(metadata, arrayConfig),
                    propsNullable: (0, orm_helper_1.getPropsNullable)(metadata),
                    primaryColumnName: (0, orm_helper_1.getPrimaryColumnName)(metadata),
                    primaryColumnType: (0, orm_helper_1.getPrimaryColumnType)(metadata),
                    propsArrayType: (0, orm_helper_1.getArrayType)(metadata),
                    typeName: (0, change_case_commonjs_1.kebabCase)(className),
                    className: className,
                    relations: (0, orm_helper_1.getRelation)(metadata),
                    relationProperty: (0, orm_helper_1.getRelationProperty)(metadata),
                });
            }
            return mapProperty;
        },
    };
}
function RunInTransactionFactory() {
    return {
        provide: json_api_nestjs_1.RUN_IN_TRANSACTION_FUNCTION,
        inject: [],
        useFactory() {
            return async (callback) => callback();
        },
    };
}
function OrmServiceFactory() {
    return {
        provide: json_api_nestjs_1.ORM_SERVICE,
        useClass: service_1.MicroOrmService,
    };
}
function FindOneRowEntityFactory() {
    return {
        provide: json_api_nestjs_1.FIND_ONE_ROW_ENTITY,
        inject: [micro_orm_util_service_1.MicroOrmUtilService],
        useFactory(microOrmUtilService) {
            return async (entity, value) => {
                return microOrmUtilService
                    .queryBuilder(entity)
                    .where({
                    [microOrmUtilService.currentPrimaryColumn]: value,
                })
                    .getSingleResult();
            };
        },
    };
}
//# sourceMappingURL=index.js.map