import { EntityClass, EntityKey, EntityProperty, type QBFilterQuery, QBQueryOrderMap, EntityData } from '@mikro-orm/core';
import { Knex, SqlEntityManager, QueryBuilder } from '@mikro-orm/knex';
import { Query, QueryOne, Relationships } from '@klerick/json-api-nestjs';
import { RelationKeys } from '@klerick/json-api-nestjs-shared';
export type InputValidateData = {
    type: string;
    id: string;
};
export type ValidateReturn<T> = T extends unknown[] ? string[] : T extends null ? null : string;
export declare class MicroOrmUtilService<E extends object, IdKey extends string = 'id'> {
    readonly entityManager: SqlEntityManager;
    private entityRepository;
    readonly entity: EntityClass<E>;
    private _relationsName;
    private _relationMap;
    private _relationPropsMap;
    get relationsName(): EntityKey<E, false>[];
    getRelationProps(entity: EntityClass<E>): EntityKey<E, false>[];
    getRelation(name: EntityKey<E, false>): EntityProperty<E, any>;
    get currentAlias(): string;
    get metadata(): import("@mikro-orm/core").EntityMetadata<E>;
    get currentPrimaryColumn(): EntityKey<E, false>;
    get defaultOrder(): QBQueryOrderMap<E>;
    getAliasForEntity<T = E>(entity: EntityClass<T>): string;
    getAliasForPivotTable<T = E>(relName: keyof T): string;
    getAliasForPivotTable<T = E>(entity: EntityClass<T>, relName: keyof T): string;
    queryBuilder<T extends object = E>(entity: EntityClass<T>, alias: string): QueryBuilder<T, typeof alias>;
    queryBuilder<T extends object = E>(entity: EntityClass<T>): QueryBuilder<T, string>;
    queryBuilder<T extends object = E>(alias: string): QueryBuilder<T, typeof alias>;
    queryBuilder<T extends object = E>(): QueryBuilder<T, string>;
    getFilterExpressionForTarget<T extends object = E>(query: Query<T, IdKey>): QBFilterQuery<T>[];
    getConditionalForJoin<T extends object = E>(query: Query<T, IdKey>, key: string): QBFilterQuery;
    private extractedResultOperand;
    getFilterExpressionForRelation<T extends object = E>(query: Query<T, IdKey>): QBFilterQuery<T>[];
    getKnex(): Knex<E, E[]>;
    prePareQueryBuilder(queryBuilder: QueryBuilder<E>, query: Query<E, IdKey> | QueryOne<E, IdKey>): QueryBuilder<E>;
    getPrimaryNameFor(rel: RelationKeys<E, IdKey>): EntityKey<E, false>;
    private getFilterObject;
    private getSubQueryForRelation;
    private getInverseFieldForManyToMany;
    createEntity(params: EntityData<E>): E;
    private asyncIterateFindRelationships;
    saveEntity(targetInstance: E, relationships?: Relationships<E, IdKey>): Promise<E>;
    validateRelationInputData<Rel extends RelationKeys<E, IdKey>, In extends InputValidateData | InputValidateData[]>(rel: Rel, inputData: In): Promise<ValidateReturn<In>>;
    validateRelationInputData<Rel extends RelationKeys<E, IdKey>, In extends InputValidateData | InputValidateData[]>(rel: Rel, inputData: In): Promise<ValidateReturn<In>>;
    validateRelationInputData<Rel extends RelationKeys<E, IdKey>, In extends null | InputValidateData | InputValidateData[]>(rel: Rel, inputData: In): Promise<ValidateReturn<In>>;
}
